*******************************************************************************
** MRM.do, created in Stata version 15.1                                     **
** Illlustation of the Mean Rank Method for mapping x to y                   **
** For details please see Wee HL et al., Medical Decision Making 2018        **  
** and Cheung YB et al. Quality of Life Research 2019                        **
** Note:                                                                     **                                                          
** x is the variable names for the (numeric) predictor variable              **
** y is the variable names for the (numeric) target variable                 **
** sorted_y.dta  is an intermediate file name                                **
** mapped_xy.dta is output file with individual records of x, y and mapped y **
** map_table.dta is the table for mapping each observed x value to y         **
*******************************************************************************
 
clear
set more off
version 15.1
set seed 12345

* generate an example dataset

set obs 10
gen id=_n
gen x=round(10*runiform(),1)
gen y=10+5*x+round(rnormal(0,10),1)
list

* remove rows with missing x or y values, if any

keep x y
drop if x==. | y==.

* generate sorted y's

preserve
keep y
sort y
save sorted_y, replace
restore

* merged sorted x's and y's

keep x
sort x
merge 1:1 _n using sorted_y
tab _merge
drop _merge

* map x to y
* genertae individual records file
 
sort x
qui by x: egen mapped_y=mean(y)
order x y mapped_y
save mapped_xy, replace

* generate mapping table

drop y 
qui by x: drop if _n>1
save map_table, replace

* erase unnecessary files

erase sorted_y.dta

